@@ -98,6 +98,8 @@ its name. This option must not appear in combination with the C<values> option.
 Each value shall be on one line, with no headers, no intervening whitespace no
 comments and no empty lines.
 
+The file is expected to be encoded in UTF-8.
+
 =item range
 
 In case of integer and numeric features, an allowed range can be specified
@@ -153,13 +155,17 @@ in scalar context.
 
 =head2 Creating the features object
 
-Data::FeatureFactory has two methods: C<new> and C<evaluate>. C<new> creates an
+The C<new> method creates an
 object that can then be used to evaluate features. Please do *not* override the
 C<new> method. If you do, then be sure that it calls
 C<Data::FeatureFactory::new> properly. This method accepts an optional
 argument - a hashref with options. Currently, only the 'N/A' option is
 supported. See below for details.
 
+=head2 Getting the list of defined features
+
+The C<names> method returns a list of names of all the features defined.
+
 =head2 Evaluating features
 
 The C<evaluate> method of Data::FeatureFactory takes these
@@ -236,8 +242,22 @@ use strict;
 use Carp;
 use File::Basename;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03-r2';
 my $PATH = &{ sub { return dirname( (caller)[1] ) } };
+my $OPEN_OPTIONS;
+
+# check if perl can open files in utf8
+undef $@;
+{
+    my $fh;
+    eval { open $fh, '<:encoding(utf8)', $0 };
+    if ($@) {
+        $OPEN_OPTIONS = '';
+        warn qq{the open's :encoding directive not supported by your perl ($]). Files won't be opened in utf8 format.};
+    }
+    else    { $OPEN_OPTIONS = ':encoding(utf8)' }
+    close $fh;
+}
 
 sub new : method {
     croak 'Too many parameters' if @_ > 2;
@@ -317,7 +337,7 @@ sub new : method {
                 my $ppname;
                 if (defined $package_name and length $package_name > 0) {
                     $package_name =~ s/::$//;
-                    push @INC, $self->{'caller_path'};
+                    local @INC = (@INC, $self->{'caller_path'});
                     undef $@;
                     eval "require $package_name";
                     if ($@) {
@@ -331,11 +351,11 @@ sub new : method {
                 $postprocsub = \&{$ppname};
                 undef $@;
                 eval { $postprocsub->() };
-                if ($@) {
+                if ($@ =~ /^Undefined subroutine/) {
                     croak "Couldn't load postprocessing function '$postproc' ($@)"
                 }
             }
-            elsif ($@) {
+            elsif ($@ =~ /^Undefined subroutine/) {
                 croak "Couldn't load postprocessing function '$postproc' ($@)"
             }
             $feature->{'postproc'} = $postprocsub;
@@ -368,9 +388,9 @@ sub new : method {
         
         if (exists $feature->{'values_file'}) {
             my $values_fn = $feature->{'values_file'};
-            my $opened = open my $values_fh, '<:encoding(utf8)', $values_fn;
+            my $opened = open my $values_fh, '<'.$OPEN_OPTIONS, $values_fn;
             if (not $opened) {
-                open $values_fh, '<:encoding(utf8)', $self->{'caller_path'}.'/'.$values_fn
+                open $values_fh, '<'.$OPEN_OPTIONS, $self->{'caller_path'}.'/'.$values_fn
                     or croak "Couldn't open file '$values_fn' specifying values for $name"
             }
             my %values;
@@ -756,7 +776,7 @@ sub _create_mapping : method {
             my $num_value_max = 0;
             FILENAME_R:
             for my $fn (@filenames_to_try) {
-                $opened = open my $fh, '+<:encoding(utf8)', $fn;
+                $opened = open my $fh, '+<'.$OPEN_OPTIONS, $fn;
                 if ($opened) {
                     local $_;   # for some reason, this is necessary to prevent crashes (Modification of read-only value) when e.g. in for(qw(a b)){ }
                     while (<$fh>) {
@@ -773,7 +793,7 @@ sub _create_mapping : method {
             }
             # If there's no file to recover from, try to start a new one
             if (not $opened) { FILENAME_W: for my $fn (@filenames_to_try) {
-                $opened = open my $fh, '>:encoding(utf8)', $fn;
+                $opened = open my $fh, '>'.$OPEN_OPTIONS, $fn;
                 if ($opened) {
                     print STDERR "Saving the mapping for feature '$name' to file $fn\n";
                     $feature->{'num_values_fh'} = $fh;
@@ -841,6 +861,11 @@ sub _create_mapping : method {
     }
 }
 
+sub names : method {
+    my ($self) = @_;
+    return map $_->{'name'}, @{ $self->{'features'} }
+}
+
 # to delete
 sub spit {
     my ($self, $featname) = @_;
